@@ -2,5 +2,5 @@ import pytz
 
 
 def get_utc_timestamp(dt):
-    mytz = pytz.timezone('UTC')
+    mytz = pytz.timezone("UTC")
     return mytz.normalize(mytz.localize(dt, is_dst=False))
